[hide private]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- pyxmpp.cache.Cache: Caching proxy for object retrieval and caching.
- pyxmpp.cache.CacheFetcher: Base class for cache object fetchers -- classes responsible for retrieving objects from network.
  - pyxmpp.jabber.disco.DiscoCacheFetcherBase: Base class for disco cache fetchers.
- pyxmpp.cache.CacheSuite: Caching proxy for object retrieval and caching.
- pyxmpp.client.Client: Base class for an XMPP-IM client.
  - pyxmpp.jabber.client.JabberClient: Base class for a Jabber client.
- pyxmpp.sasl.core.ClientAuthenticator: Base class for client authenticators.
  - pyxmpp.sasl.digest_md5.DigestMD5ClientAuthenticator: Provides PLAIN SASL authentication for a client.
  - pyxmpp.sasl.plain.PlainClientAuthenticator: Provides PLAIN SASL authentication for a client.
- pyxmpp.jabberd.component.Component: Jabber external component ("jabber:component:accept" protocol) interface implementation.
- pyxmpp.error.ErrorNode: Base class for both XMPP stream and stanza errors
  - pyxmpp.error.StanzaErrorNode: Stanza error element.
  - pyxmpp.error.StreamErrorNode: Stream error element.
- pyxmpp.xmppstringprep.LookupFunction: Class for looking up RFC 3454 tables using function.
- pyxmpp.xmppstringprep.LookupTable: Class for looking up RFC 3454 tables using a dictionary and/or list of ranges.
- pyxmpp.jabber.muc.MucRoomHandler: Base class for MUC room handlers.
- pyxmpp.jabber.muc.MucRoomManager: Manage collection of MucRoomState objects and dispatch events.
- pyxmpp.jabber.muc.MucRoomState: Describes the state of a MUC room, handles room events and provides an interface for room actions.
- pyxmpp.jabber.muc.MucRoomUser: Describes a user of a MUC room.
- pyxmpp.jabber.muccore.MucStanzaExt: Base class for MUC specific stanza extensions.
  - pyxmpp.jabber.muccore.MucIq: Extend Iq with MUC related interface.
  - pyxmpp.jabber.muccore.MucPresence: Extend Presence with MUC related interface.
- pyxmpp.sasl.core.PasswordManager: Base class for password managers.
  - pyxmpp.streamsasl.StreamSASLMixIn: SASL authentication mix-in class for XMPP stream.
    - pyxmpp.stream.Stream: Generic XMPP stream class.
      - pyxmpp.clientstream.ClientStream: Handles XMPP-IM client connection stream.
        - pyxmpp.jabber.clientstream.LegacyClientStream: Handles Jabber (both XMPP and legacy protocol) client connection stream.
      - pyxmpp.jabberd.componentstream.ComponentStream: Handles jabberd component (jabber:component:accept) connection stream.
- pyxmpp.xmppstringprep.Profile: Base class for stringprep profiles.
- pyxmpp.sasl.core.Reply: Base class for SASL authentication reply objects.
  - pyxmpp.sasl.core.Challenge: The challenge SASL message (server's challenge for the client).
  - pyxmpp.sasl.core.Failure: The failure SASL message.
  - pyxmpp.sasl.core.Response: The response SASL message (clients's reply the the server's challenge).
  - pyxmpp.sasl.core.Success: The success SASL message (sent by the server on authentication success).
- libxml2.SAXCallback
- pyxmpp.sasl.core.ServerAuthenticator: Base class for server authenticators.
  - pyxmpp.sasl.digest_md5.DigestMD5ServerAuthenticator: Provides DIGEST-MD5 SASL authentication for a server.
  - pyxmpp.sasl.plain.PlainServerAuthenticator: Provides PLAIN SASL authentication for a server.
- pyxmpp.stanza.Stanza: Base class for all XMPP stanzas.
  - pyxmpp.iq.Iq: Wraper object for <iq /> stanzas.
    - pyxmpp.jabber.muccore.MucIq: Extend Iq with MUC related interface.
  - pyxmpp.message.Message: Wraper object for <message /> stanzas.
  - pyxmpp.presence.Presence: Wraper object for <presence /> stanzas.
    - pyxmpp.jabber.muccore.MucPresence: Extend Presence with MUC related interface.
- pyxmpp.stanzaprocessor.StanzaProcessor: Universal stanza handler/router class.
  - pyxmpp.streambase.StreamBase: Base class for a generic XMPP stream.
    - pyxmpp.stream.Stream: Generic XMPP stream class.
      - pyxmpp.clientstream.ClientStream: Handles XMPP-IM client connection stream.
        - pyxmpp.jabber.clientstream.LegacyClientStream: Handles Jabber (both XMPP and legacy protocol) client connection stream.
      - pyxmpp.jabberd.componentstream.ComponentStream: Handles jabberd component (jabber:component:accept) connection stream.
- pyxmpp.xmlextra.StreamHandler: Base class for stream handler.
  - pyxmpp.streambase.StreamBase: Base class for a generic XMPP stream.
    - pyxmpp.stream.Stream: Generic XMPP stream class.
      - pyxmpp.clientstream.ClientStream: Handles XMPP-IM client connection stream.
        - pyxmpp.jabber.clientstream.LegacyClientStream: Handles Jabber (both XMPP and legacy protocol) client connection stream.
      - pyxmpp.jabberd.componentstream.ComponentStream: Handles jabberd component (jabber:component:accept) connection stream.
- pyxmpp.xmlextra.StreamReader: A simple push-parser interface for XML streams.
- pyxmpp.streamtls.StreamTLSMixIn: Mix-in class providing TLS support for an XMPP stream.
  - pyxmpp.stream.Stream: Generic XMPP stream class.
    - pyxmpp.clientstream.ClientStream: Handles XMPP-IM client connection stream.
      - pyxmpp.jabber.clientstream.LegacyClientStream: Handles Jabber (both XMPP and legacy protocol) client connection stream.
    - pyxmpp.jabberd.componentstream.ComponentStream: Handles jabberd component (jabber:component:accept) connection stream.
- pyxmpp.streamtls.TLSSettings: Storage for TLS-related settings of an XMPP stream.
- pyxmpp.jabber.vcard.VCardField: Base class for vCard fields.
  - pyxmpp.jabber.vcard.VCardAdr: Address vCard field.
  - pyxmpp.jabber.vcard.VCardCategories: Categories vCard field.
  - pyxmpp.jabber.vcard.VCardEmail: E-mail vCard field.
  - pyxmpp.jabber.vcard.VCardGeo: Geographical location vCard field.
  - pyxmpp.jabber.vcard.VCardImage: Image vCard field.
  - pyxmpp.jabber.vcard.VCardJID: JID vCard field.
  - pyxmpp.jabber.vcard.VCardKey: Key vCard field.
  - pyxmpp.jabber.vcard.VCardLabel: Address label vCard field.
  - pyxmpp.jabber.vcard.VCardName: Name vCard field.
  - pyxmpp.jabber.vcard.VCardOrg: Organization vCard field.
  - pyxmpp.jabber.vcard.VCardPrivacy: Privacy vCard field.
  - pyxmpp.jabber.vcard.VCardSound: Sound vCard field.
  - pyxmpp.jabber.vcard.VCardString: Generic class for all standard text fields in the vCard.
    - pyxmpp.jabber.vcard.VCardXString: Generic class for all text vCard fields not defined in RFC 2426.
  - pyxmpp.jabber.vcard.VCardTel: Telephone vCard field.
- pyxmpp.xmlextra._PythonReader: Python-only stream reader.
- object: The most base type
  - pyxmpp.interface_micro_impl.Attribute
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - pyxmpp.jabber.vcard.Empty: Exception raised when parsing empty vcard element.
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - pyxmpp.exceptions.Error: Base class for all PyXMPP exceptions.
          - pyxmpp.exceptions.ClientError: Raised on a client error.
            - pyxmpp.exceptions.FatalClientError: Raised on a fatal client error.
          - pyxmpp.exceptions.JIDError: Exception raised when invalid JID is used
            - pyxmpp.exceptions.JIDMalformedProtocolError: Raised when invalid JID is encountered.
          - pyxmpp.exceptions.ProtocolError: Raised when there is something wrong with a stanza processed.
            - pyxmpp.exceptions.BadRequestProtocolError: Raised when invalid stanza is processed and 'bad-request' error should be reported.
            - pyxmpp.exceptions.FeatureNotImplementedProtocolError: Raised when stanza requests a feature which is not (yet) implemented.
            - pyxmpp.exceptions.JIDMalformedProtocolError: Raised when invalid JID is encountered.
          - pyxmpp.exceptions.StreamError: Base class for all stream errors.
            - pyxmpp.exceptions.ClientStreamError: Raised on a client stream error.
              - pyxmpp.exceptions.LegacyAuthenticationError: Raised on a legacy authentication error.
              - pyxmpp.exceptions.RegistrationError: Raised on a in-band registration error.
            - pyxmpp.exceptions.ComponentStreamError: Raised on a component error.
              - pyxmpp.exceptions.FatalComponentStreamError: Raised on a fatal component error.
            - pyxmpp.exceptions.FatalStreamError: Base class for all fatal Stream exceptions.
              - pyxmpp.exceptions.FatalClientStreamError: Raised on a fatal client stream error.
              - pyxmpp.exceptions.FatalComponentStreamError: Raised on a fatal component error.
              - pyxmpp.exceptions.StreamAuthenticationError: Raised when stream authentication fails.
                - pyxmpp.exceptions.SASLAuthenticationFailed: Raised when stream SASL authentication fails.
                - pyxmpp.exceptions.SASLMechanismNotAvailable: Raised when none of SASL authentication mechanisms requested is available.
                - pyxmpp.exceptions.SASLNotAvailable: Raised when SASL authentication is requested, but not available.
              - pyxmpp.exceptions.StreamParseError: Raised when invalid XML is received in an XMPP stream.
              - pyxmpp.exceptions.TLSError: Raised on TLS error during stream processing.
                - pyxmpp.exceptions.TLSNegotiatedButNotAvailableError: Raised on TLS error during stream processing.
              - pyxmpp.exceptions.TLSNegotiationFailed: Raised when stream TLS negotiation fails.
            - pyxmpp.exceptions.HostMismatch: Exception raised when the connected host name is other then requested.
            - pyxmpp.exceptions.StreamEncryptionRequired: Exception raised when stream encryption is requested, but not used.
          - pyxmpp.exceptions.StringprepError: Exception raised when string preparation results in error.
        - exceptions.ValueError: Inappropriate argument value (of correct type).
          - pyxmpp.exceptions.JIDError: Exception raised when invalid JID is used
            - pyxmpp.exceptions.JIDMalformedProtocolError: Raised when invalid JID is encountered.
  - pyxmpp.cache.CacheItem: An item in a cache.
  - pyxmpp.jabber.muccore.HistoryParameters: Provides parameters for MUC history management
  - pyxmpp.interface_micro_impl.InterfaceClass
  - pyxmpp.jid.JID: JID.
  - pyxmpp.jabber.muccore.MucItemBase: Base class for <status/> and <item/> element wrappers.
    - pyxmpp.jabber.muccore.MucItem: MUC <item/> element -- describes a room occupant.
    - pyxmpp.jabber.muccore.MucStatus: MUC <item/> element - describes special meaning of a stanza
  - pyxmpp.objects.StanzaPayloadObject: Base class for objects that may be used as XMPP stanza payload and don't keep internal XML representation, only parsed values.
    - pyxmpp.jabber.delay.Delay: Delayed delivery tag.
    - pyxmpp.jabber.dataforms.Field: A data form field.
    - pyxmpp.jabber.dataforms.Form: A JEP-0004 compliant data form.
    - pyxmpp.jabber.dataforms.Item: An item of multi-item form data (e.g.
    - pyxmpp.jabber.dataforms.Option: One of optional data form field values.
    - pyxmpp.jabber.register.Register: Delayed delivery tag.
    - pyxmpp.roster.Roster: Class representing XMPP-IM roster.
    - pyxmpp.roster.RosterItem: Roster item.
    - pyxmpp.jabber.vcard.VCard: Jabber (vcard-temp) or RFC2426 vCard.
  - pyxmpp.objects.StanzaPayloadWrapperObject: Base class for objects that may be used as XMPP stanza payload and maintain an internal XML representation of self.
    - pyxmpp.jabber.disco.DiscoIdentity: An <identity/> element of disco#info reply.
    - pyxmpp.jabber.disco.DiscoInfo: A disco#info response object.
    - pyxmpp.jabber.disco.DiscoItem: An item of disco#items reply.
    - pyxmpp.jabber.disco.DiscoItems: A disco#items response or publish-request object.
    - pyxmpp.jabber.muccore.MucXBase: Base class for MUC-specific stanza payload - wrapper around an XML element.
      - pyxmpp.jabber.muccore.MucOwnerX: Wrapper for http://www.jabber.org/protocol/muc#owner namespaced stanza payload "x" elements and usually containing information about a room user.
      - pyxmpp.jabber.muccore.MucUserX: Wrapper for http://www.jabber.org/protocol/muc#user namespaced stanza payload "x" elements and usually containing information about a room user.
        - pyxmpp.jabber.muccore.MucAdminQuery: Wrapper for http://www.jabber.org/protocol/muc#admin namespaced IQ stanza payload "query" elements and usually describing administrative actions or their results.
      - pyxmpp.jabber.muccore.MucX: Wrapper for http://www.jabber.org/protocol/muc namespaced stanza payload "x" elements.
  - dict: dict() -> new empty dictionary.
    - pyxmpp.expdict.ExpiringDictionary: An extension to standard Python dictionary objects which implements item expiration.